%   Version History:
%   1 Mar 2016 - Initial release.
%
%  Copyright (c) 2016, Okan Tarhan Tursun
%

classdef HDRScene
    properties
        dirname    % directory where the tiff files with linear-CRF reside
        imSet      % set of images
        expT       % exposure times
        relEV      % relative exposure values
        scenename  % scene name
    end
    methods
        function obj = HDRScene(d)
            obj.dirname = d;
            [~, name, ~] = fileparts(d);
            obj.scenename = name;
            files = dir(fullfile(d, '*.tiff'));
            obj.imSet = cell(numel(files),1);
            obj.expT = zeros(numel(files),1);
            obj.relEV = zeros(numel(files),1);
            for i=1:numel(files)
                obj.imSet{i} = imread(fullfile(d, files(i).name));
                obj.imSet{i} = im2double(obj.imSet{i});
                [~, name, ~] = fileparts(files(i).name);
                fid = fopen(fullfile(d, [name '.txt']), 'r');
                line = fgetl(fid);
                line = strtrim(line);

                % read exposure times from the textfile of meta-data
                expTime = regexp(line, '\s', 'split');
                expTime = expTime{2};
                expTime = regexp(expTime, '\/', 'split');
                if numel(expTime) == 1
                    expTime = str2double(expTime);
                else
                    expTime = str2double(expTime{1}) / str2double(expTime{2});
                end
                obj.expT(i) = expTime;
                fclose(fid);
            end
            midExpInd = floor(numel(files)/2+0.5);
            % set the relative exposures (relEV of middle exposure is zero)
            for i=1:numel(files)
                obj.relEV(i) = log2(obj.expT(i) / obj.expT(midExpInd));
            end

            % sort imSet, expT and relEV with respect to ascending EV
            [~, order] = sortrows(obj.relEV);
            obj.relEV = obj.relEV(order, :);
            obj.imSet = obj.imSet(order, :);
            obj.expT = obj.expT(order, :);
            

        end
    end
end
