function [gradDirDiff, gradMagDiff] = gradInconst(radIm, hdrIm, scale, tau)
%GRADINCONST Function for calculating the gradient inconsistency

%   Version History:
%   1 Mar 2016 - Initial release.
%
%  Copyright (c) 2016, Okan Tarhan Tursun
%

numIm = numel(radIm);
origSize = [size(hdrIm,1) size(hdrIm,2)];


if scale ~= 1
    for i = 1:numIm
        radIm{i} = imresize(radIm{i}, scale);
    end
    hdrIm = imresize(hdrIm, scale);
end


gradDir = zeros([size(radIm{1},1) size(radIm{1},2) numIm]);
gradMag = zeros([size(radIm{1},1) size(radIm{1},2) numIm]);
gradMagDiff = zeros(size(gradMag));

for i = 1:numIm
    [gradMag(:,:,i), gradDir(:,:,i)] = imgradient(mean(radIm{i},3));
end
[gradMagHdr, gradDirHdr] = imgradient(mean(hdrIm,3));
b = mean(gradMagHdr(:));

gradDirDiff = zeros(size(gradDir));
for i = 1:numIm
    gradDirDiff(:,:,i) = abs(mod((gradDir(:,:,i) - gradDirHdr) + 180, 360) - 180);
    a = gradMag(:,:,i);
    a = mean(a(:));
    tmp = abs(gradMag(:,:,i) - gradMagHdr / b * a) ./ (max(gradMag(:,:,i), gradMagHdr / b * a) + 1E-6);
    tmp(tmp <= tau) = 0;
    gradMagDiff(:,:,i) = tmp;
end
gradDirDiff = min(gradDirDiff, [], 3);
gradDirDiff = gradDirDiff / 180;

gradMagDiff = min(gradMagDiff, [], 3);
if scale ~= 1
    gradDirDiff = imresize(gradDirDiff, origSize, 'bilinear');
    gradMagDiff = imresize(gradMagDiff, origSize, 'bilinear');
end

end

