% maindir = fullfile(fileparts(pwd), 'mug_outputs', 'Mug2');
maindir = fullfile(fileparts(fileparts(pwd)), 'Inputs');

id = 'MATLAB:interp1:UsePCHIP';
warning('off',id);

scenes_dir = fullfile(maindir, 'InputImages');
results_dir = fullfile(maindir, 'Outputs');

scenes = dir(fullfile(scenes_dir, '*'));
scenes(1:2) = [];
algorithms = dir(fullfile(results_dir, '*'));
algorithms(1:2) = [];
notdir = [];
for i = 1:numel(algorithms)
    if  ~algorithms(i).isdir
        notdir(end+1) = i;
    end
end
algorithms(notdir) = [];

tmp_dir = fullfile(pwd, 'tmp');

outputs_root = fullfile(pwd, 'outputs');
if ~exist(outputs_root, 'dir')
    mkdir(outputs_root);
end

for i=1:numel(scenes)
    im_files = dir(fullfile(scenes_dir, scenes(i).name, '*.tiff'));
    scenes(i).imSet = cell(numel(im_files),1);
    scenes(i).expT = zeros(numel(im_files),1);
    for j=1:numel(scenes(i).imSet)
        [~, name, ~] = fileparts(im_files(j).name);
        info_file = [name '.txt'];
        
        txtfid = fopen(fullfile(scenes_dir, scenes(i).name, info_file), 'r');
        str = fgetl(txtfid);
        str = strtrim(str);
        str = regexp(str, '\s', 'split');
        exptime = regexp(str(1,2), '\/', 'split');
        if numel(exptime{1}) == 2
            exptime = str2double(exptime{1}(1,1)) / str2double(exptime{1}(1,2));
            exptime = 1 / exptime;
        else
            exptime = 1 / str2double(exptime{1});
        end
        fclose(txtfid);
        scenes(i).expT(j) = 1/exptime;
        
        scenes(i).imSet{j} = imread(fullfile(scenes_dir, scenes(i).name, im_files(j).name));
    end
end

skip_list = {'2012Silk-naive', '2012Silk-pwd'}; % , 'SimpleDeghost'

for i = 1:numel(scenes) 
    fprintf('%s\n', scenes(i).name);
    for j = [1 2 3 4 5 6 7 9 8] % 3 for Sen
        if ismember(algorithms(j).name, skip_list)
            continue
        end
        fprintf('%s\t', algorithms(j).name);
        outputs_dir = fullfile(outputs_root, scenes(i).name, algorithms(j).name);
        if exist(fullfile(outputs_dir, 'variables.mat'), 'file')
            continue
        end
        hdrfiles = dir(fullfile(results_dir, algorithms(j).name, [scenes(i).name '*.hdr']));
        hdrIm = hdrread(fullfile(results_dir, algorithms(j).name, hdrfiles(1).name));
        imSet = scenes(i).imSet;
        expT = scenes(i).expT;
        
        middleExpIdx = floor((numel(imSet)-1)/2)+1;
        numBands = size(hdrIm,3);
        
        % workaround for simpledeghost
        if any(size(hdrIm) ~= size(imSet{1}))
            padsize = [size(imSet{1},1)-size(hdrIm,1) size(imSet{1},2)-size(hdrIm,2)];
            hdrIm = padarray(hdrIm, padsize, 0, 'post');
            radIm = im2double(imSet{middleExpIdx}) ./ expT(middleExpIdx);
            radIm = radIm ./ mean(radIm(:)) .* mean(hdrIm(:));
            for c =1:numBands
                hdrIm((end-padsize(1)):end, :, c) = ...
                    radIm((end-padsize(1)):end, :, c);
                hdrIm(:, (end-padsize(2)):end, c) = ...
                    radIm(:, (end-padsize(2)):end, c);
            end
        end
        
        test = hdrIm;
        res = cell(numel(imSet), 1);
        pmap = zeros([size(imSet{1},1) size(imSet{1},2) numel(imSet)]);
        
        for n=1:numel(imSet)
            reference = imSet{n};
            res{n} = hdrvdp(test / mean(test(:)), im2double(reference) / mean(mean(mean(im2double(reference)))), 'rgb-bt.709', 30);
            pmap(:,:,n) = res{n}.P_map;
        end
        minpmap = min(pmap,[],3);
        avgscore = mean(minpmap(:));
        
%         [ bMap, hdrImDRClip, globalDR, dynRegionDR, var ] = dqm( imSet, expT, hdrIm, tmp_dir );
%         var.bMap(var.bMap < bMapThresh) = 0;
%         var.gradMagDiff(var.gradMagDiff < gradMagThresh) = 0;
               
        if ~exist(outputs_dir, 'dir')
            mkdir(outputs_dir);
        end
        save(fullfile(outputs_dir, 'variables.mat'), 'pmap', 'minpmap', 'avgscore');
        imwrite(minpmap, fullfile(outputs_dir, 'pmap.png'));
        fprintf('%#.6g\n', avgscore);
    end
end
warning('on',id);
